@@ -1,6 +1,5 @@
 from __future__ import unicode_literals
 
-import re
 
 from .common import InfoExtractor
 from ..compat import compat_str
@@ -76,7 +75,7 @@ class MxplayerIE(InfoExtractor):
                     yield stream_type, 'base', stream
 
     def _real_extract(self, url):
-        display_id, video_id = re.match(self._VALID_URL, url).groups()
+        display_id, video_id = self._match_valid_url(url).groups()
         webpage = self._download_webpage(url, video_id)
 
         source = self._parse_json(
@@ -110,10 +109,15 @@ class MxplayerIE(InfoExtractor):
                 for frmt in dash_formats:
                     frmt['quality'] = get_quality(quality)
                 formats.extend(dash_formats)
+                dash_formats_h265 = self._extract_mpd_formats(
+                    format_url.replace('h264_high', 'h265_main'), video_id, mpd_id='dash-%s' % quality, headers={'Referer': url}, fatal=False)
+                for frmt in dash_formats_h265:
+                    frmt['quality'] = get_quality(quality)
+                formats.extend(dash_formats_h265)
             elif stream_type == 'hls':
                 formats.extend(self._extract_m3u8_formats(
                     format_url, video_id, fatal=False,
-                    m3u8_id='hls-%s' % quality, quality=get_quality(quality)))
+                    m3u8_id='hls-%s' % quality, quality=get_quality(quality), ext='mp4'))
 
         self._sort_formats(formats)
         return {
@@ -165,7 +169,7 @@ class MxplayerShowIE(InfoExtractor):
                 next_url = season_json.get('next')
 
     def _real_extract(self, url):
-        display_id, show_id = re.match(self._VALID_URL, url).groups()
+        display_id, show_id = self._match_valid_url(url).groups()
         return self.playlist_result(
             self._entries(show_id), playlist_id=show_id,
             playlist_title=display_id.replace('-', ' ').title())
