@@ -1,11 +1,9 @@
 # coding: utf-8
 from __future__ import unicode_literals
 
-import re
 
 from .common import InfoExtractor
 from ..utils import (
-    ExtractorError,
     float_or_none,
     int_or_none,
     parse_iso8601,
@@ -20,7 +18,7 @@ class NineCNineMediaIE(InfoExtractor):
     _API_BASE_TEMPLATE = 'http://capi.9c9media.com/destinations/%s/platforms/desktop/contents/%s/'
 
     def _real_extract(self, url):
-        destination_code, content_id = re.match(self._VALID_URL, url).groups()
+        destination_code, content_id = self._match_valid_url(url).groups()
         api_base_url = self._API_BASE_TEMPLATE % (destination_code, content_id)
         content = self._download_json(api_base_url, content_id, query={
             '$include': '[Media.Name,Season,ContentPackages.Duration,ContentPackages.Id]',
@@ -36,7 +34,7 @@ class NineCNineMediaIE(InfoExtractor):
 
         if (not self.get_param('allow_unplayable_formats')
                 and try_get(content_package, lambda x: x['Constraints']['Security']['Type'])):
-            raise ExtractorError('This video is DRM protected.', expected=True)
+            self.report_drm(content_id)
 
         manifest_base_url = content_package_url + 'manifest.'
         formats = []
